@@ -193,7 +193,7 @@ class APIGatewayResponse(BaseResponse):
             authorizer_id = self._get_param("authorizerId")
             authorization_scopes = self._get_param("authorizationScopes")
             request_validator_id = self._get_param("requestValidatorId")
-            method = self.backend.create_method(
+            method = self.backend.put_method(
                 function_id,
                 resource_id,
                 method_type,
@@ -234,7 +234,7 @@ class APIGatewayResponse(BaseResponse):
         elif self.method == "PUT":
             response_models = self._get_param("responseModels")
             response_parameters = self._get_param("responseParameters")
-            method_response = self.backend.create_method_response(
+            method_response = self.backend.put_method_response(
                 function_id,
                 resource_id,
                 method_type,
@@ -289,9 +289,9 @@ class APIGatewayResponse(BaseResponse):
                 )
 
             authorizer_response = self.backend.create_authorizer(
-                restapi_id,
-                name,
-                authorizer_type,
+                restapi_id=restapi_id,
+                name=name,
+                authorizer_type=authorizer_type,
                 provider_arns=provider_arns,
                 auth_type=auth_type,
                 authorizer_uri=authorizer_uri,
@@ -482,7 +482,7 @@ class APIGatewayResponse(BaseResponse):
                     "httpMethod"
                 )  # default removed because it's a required parameter
 
-                integration_response = self.backend.create_integration(
+                integration_response = self.backend.put_integration(
                     function_id,
                     resource_id,
                     method_type,
@@ -526,7 +526,7 @@ class APIGatewayResponse(BaseResponse):
                 selection_pattern = self._get_param("selectionPattern")
                 response_templates = self._get_param("responseTemplates")
                 content_handling = self._get_param("contentHandling")
-                integration_response = self.backend.create_integration_response(
+                integration_response = self.backend.put_integration_response(
                     function_id,
                     resource_id,
                     method_type,
