@@ -179,6 +179,7 @@ class BatchResponse(BaseResponse):
         tags = self._get_param("tags")
         retry_strategy = self._get_param("retryStrategy")
         _type = self._get_param("type")
+        timeout = self._get_param("timeout")
         try:
             name, arn, revision = self.batch_backend.register_job_definition(
                 def_name=def_name,
@@ -187,6 +188,7 @@ class BatchResponse(BaseResponse):
                 tags=tags,
                 retry_strategy=retry_strategy,
                 container_properties=container_properties,
+                timeout=timeout,
             )
         except AWSError as err:
             return err.response()
@@ -231,6 +233,7 @@ class BatchResponse(BaseResponse):
         job_queue = self._get_param("jobQueue")
         parameters = self._get_param("parameters")
         retries = self._get_param("retryStrategy")
+        timeout = self._get_param("timeout")
 
         try:
             name, job_id = self.batch_backend.submit_job(
@@ -241,6 +244,7 @@ class BatchResponse(BaseResponse):
                 retries=retries,
                 depends_on=depends_on,
                 container_overrides=container_overrides,
+                timeout=timeout,
             )
         except AWSError as err:
             return err.response()
