@@ -1,12 +1,15 @@
 import json
 
-from boto3 import Session
-
+from moto.core import (
+    BaseBackend,
+    BaseModel,
+    CloudWatchMetricProvider,
+)
 from moto.core.utils import (
     iso_8601_datetime_without_milliseconds,
     iso_8601_datetime_with_nanoseconds,
+    BackendDict,
 )
-from moto.core import BaseBackend, BaseModel
 from datetime import datetime, timedelta
 from dateutil.tz import tzutc
 from uuid import uuid4
@@ -60,9 +63,9 @@ class MetricStat(object):
 
 class MetricDataQuery(object):
     def __init__(
-        self, id, label, period, return_data, expression=None, metric_stat=None
+        self, query_id, label, period, return_data, expression=None, metric_stat=None
     ):
-        self.id = id
+        self.id = query_id
         self.label = label
         self.period = period
         self.return_data = return_data
@@ -210,13 +213,13 @@ class MetricDatum(BaseModel):
         ]
         self.unit = unit
 
-    def filter(self, namespace, name, dimensions, already_present_metrics=[]):
+    def filter(self, namespace, name, dimensions, already_present_metrics=None):
         if namespace and namespace != self.namespace:
             return False
         if name and name != self.name:
             return False
 
-        for metric in already_present_metrics:
+        for metric in already_present_metrics or []:
             if self.dimensions and are_dimensions_same(
                 metric.dimensions, self.dimensions
             ):
@@ -258,6 +261,7 @@ class Statistics:
         self.timestamp = iso_8601_datetime_without_milliseconds(dt)
         self.values = []
         self.stats = stats
+        self.unit = None
 
     @property
     def sample_count(self):
@@ -266,10 +270,6 @@ class Statistics:
 
         return len(self.values)
 
-    @property
-    def unit(self):
-        return None
-
     @property
     def sum(self):
         if "Sum" not in self.stats:
@@ -325,9 +325,10 @@ class CloudWatchBackend(BaseBackend):
     # Retrieve a list of all OOTB metrics that are provided by metrics providers
     # Computed on the fly
     def aws_metric_data(self):
+        providers = CloudWatchMetricProvider.__subclasses__()
         md = []
-        for name, service in metric_providers.items():
-            md.extend(service.get_cloudwatch_metrics())
+        for provider in providers:
+            md.extend(provider.get_cloudwatch_metrics())
         return md
 
     def put_metric_alarm(
@@ -530,13 +531,14 @@ class CloudWatchBackend(BaseBackend):
         end_time,
         period,
         stats,
+        dimensions,
         unit=None,
-        dimensions=None,
     ):
         period_delta = timedelta(seconds=period)
+        # TODO: Also filter by unit and dimensions
         filtered_data = [
             md
-            for md in self.metric_data
+            for md in self.get_all_metrics()
             if md.namespace == namespace
             and md.name == metric_name
             and start_time <= md.timestamp <= end_time
@@ -566,6 +568,7 @@ class CloudWatchBackend(BaseBackend):
                 dt + period_delta
             ):
                 s.values.append(filtered_data[idx].value)
+                s.unit = filtered_data[idx].unit
                 idx += 1
 
             if not s.values:
@@ -676,17 +679,4 @@ class CloudWatchBackend(BaseBackend):
             return None, metrics
 
 
-cloudwatch_backends = {}
-for region in Session().get_available_regions("cloudwatch"):
-    cloudwatch_backends[region] = CloudWatchBackend(region)
-for region in Session().get_available_regions(
-    "cloudwatch", partition_name="aws-us-gov"
-):
-    cloudwatch_backends[region] = CloudWatchBackend(region)
-for region in Session().get_available_regions("cloudwatch", partition_name="aws-cn"):
-    cloudwatch_backends[region] = CloudWatchBackend(region)
-
-# List of services that provide OOTB CW metrics
-# See the S3Backend constructor for an example
-# TODO: We might have to separate this out per region for non-global services
-metric_providers = {}
+cloudwatch_backends = BackendDict(CloudWatchBackend, "cloudwatch")
