@@ -82,7 +82,7 @@ class _TemplateEnvironmentMixin(object):
     RIGHT_PATTERN = re.compile(r">[\s\n]+")
 
     def __init__(self):
-        super(_TemplateEnvironmentMixin, self).__init__()
+        super().__init__()
         self.loader = DynamicDictLoader({})
         self.environment = Environment(
             loader=self.loader, autoescape=self.should_autoescape
@@ -237,7 +237,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
                 target = request.headers.get("x-amz-target") or request.headers.get(
                     "X-Amz-Target"
                 )
-                service, method = target.split(".")
+                _, method = target.split(".")
                 input_spec = self.aws_service_spec.input_spec(method)
                 flat = flatten_json_request_body("", decoded, input_spec)
                 for key, value in flat.items():
