@@ -6,11 +6,10 @@ import json
 import re
 import uuid
 
-from boto3 import Session
 from collections import OrderedDict
 from moto.core import ACCOUNT_ID
 from moto.core import BaseBackend, BaseModel, CloudFormationModel
-from moto.core.utils import unix_time, unix_time_millis
+from moto.core.utils import unix_time, unix_time_millis, BackendDict
 from moto.core.exceptions import JsonRESTError
 from moto.dynamodb2.comparisons import get_filter_expression
 from moto.dynamodb2.comparisons import get_expected
@@ -72,11 +71,6 @@ class Item(BaseModel):
         self.hash_key = hash_key
         self.range_key = range_key
 
-        if hash_key and hash_key.size() > HASH_KEY_MAX_LENGTH:
-            raise HashKeyTooLong
-        if range_key and (range_key.size() > RANGE_KEY_MAX_LENGTH):
-            raise RangeKeyTooLong
-
         self.attrs = LimitedSizeDict()
         for key, value in attrs.items():
             self.attrs[key] = DynamoType(value)
@@ -595,6 +589,18 @@ class Table(CloudFormationModel):
             keys.append(range_key)
         return keys
 
+    def _validate_key_sizes(self, item_attrs):
+        for hash_name in self.hash_key_names:
+            hash_value = item_attrs.get(hash_name)
+            if hash_value:
+                if DynamoType(hash_value).size() > HASH_KEY_MAX_LENGTH:
+                    raise HashKeyTooLong
+        for range_name in self.range_key_names:
+            range_value = item_attrs.get(range_name)
+            if range_value:
+                if DynamoType(range_value).size() > RANGE_KEY_MAX_LENGTH:
+                    raise RangeKeyTooLong
+
     def put_item(
         self,
         item_attrs,
@@ -634,6 +640,9 @@ class Table(CloudFormationModel):
                 expected_type=self.range_key_type,
                 actual_type=range_value.type,
             )
+
+        self._validate_key_sizes(item_attrs)
+
         if expected is None:
             expected = {}
             lookup_range_value = range_value
@@ -1010,6 +1019,36 @@ class RestoredTable(Table):
         return result
 
 
+class RestoredPITTable(Table):
+    def __init__(self, name, source):
+        params = self._parse_params_from_table(source)
+        super(RestoredPITTable, self).__init__(name, **params)
+        self.indexes = copy.deepcopy(source.indexes)
+        self.global_indexes = copy.deepcopy(source.global_indexes)
+        self.items = copy.deepcopy(source.items)
+        # Restore Attrs
+        self.source_table_arn = source.table_arn
+        self.restore_date_time = self.created_at
+
+    @staticmethod
+    def _parse_params_from_table(table):
+        params = {
+            "schema": copy.deepcopy(table.schema),
+            "attr": copy.deepcopy(table.attr),
+            "throughput": copy.deepcopy(table.throughput),
+        }
+        return params
+
+    def describe(self, base_key="TableDescription"):
+        result = super(RestoredPITTable, self).describe(base_key=base_key)
+        result[base_key]["RestoreSummary"] = {
+            "SourceTableArn": self.source_table_arn,
+            "RestoreDateTime": unix_time(self.restore_date_time),
+            "RestoreInProgress": False,
+        }
+        return result
+
+
 class Backup(object):
     def __init__(
         self, backend, name, table, status=None, type_=None,
@@ -1087,7 +1126,6 @@ class DynamoDBBackend(BaseBackend):
 
     def reset(self):
         region_name = self.region_name
-
         self.__dict__ = {}
         self.__init__(region_name)
 
@@ -1690,6 +1728,22 @@ class DynamoDBBackend(BaseBackend):
         self.tables[target_table_name] = new_table
         return new_table
 
+    def restore_table_to_point_in_time(self, target_table_name, source_table_name):
+        """
+        Currently this only accepts the source and target table elements, and will
+        copy all items from the source without respect to other arguments.
+        """
+
+        source = self.get_table(source_table_name)
+        if source is None:
+            raise KeyError()
+        existing_table = self.get_table(target_table_name)
+        if existing_table is not None:
+            raise ValueError()
+        new_table = RestoredPITTable(target_table_name, source)
+        self.tables[target_table_name] = new_table
+        return new_table
+
     ######################
     # LIST of methods where the logic completely resides in responses.py
     # Duplicated here so that the implementation coverage script is aware
@@ -1706,10 +1760,4 @@ class DynamoDBBackend(BaseBackend):
         pass
 
 
-dynamodb_backends = {}
-for region in Session().get_available_regions("dynamodb"):
-    dynamodb_backends[region] = DynamoDBBackend(region)
-for region in Session().get_available_regions("dynamodb", partition_name="aws-us-gov"):
-    dynamodb_backends[region] = DynamoDBBackend(region)
-for region in Session().get_available_regions("dynamodb", partition_name="aws-cn"):
-    dynamodb_backends[region] = DynamoDBBackend(region)
+dynamodb_backends = BackendDict(DynamoDBBackend, "dynamodb")
