@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import copy
 import json
 import re
@@ -181,8 +179,20 @@ class DynamoHandler(BaseResponse):
         # getting attribute definition
         attr = body["AttributeDefinitions"]
         # getting the indexes
-        global_indexes = body.get("GlobalSecondaryIndexes", [])
-        local_secondary_indexes = body.get("LocalSecondaryIndexes", [])
+        global_indexes = body.get("GlobalSecondaryIndexes")
+        if global_indexes == []:
+            return self.error(
+                "ValidationException",
+                "One or more parameter values were invalid: List of GlobalSecondaryIndexes is empty",
+            )
+        global_indexes = global_indexes or []
+        local_secondary_indexes = body.get("LocalSecondaryIndexes")
+        if local_secondary_indexes == []:
+            return self.error(
+                "ValidationException",
+                "One or more parameter values were invalid: List of LocalSecondaryIndexes is empty",
+            )
+        local_secondary_indexes = local_secondary_indexes or []
         # Verify AttributeDefinitions list all
         expected_attrs = []
         expected_attrs.extend([key["AttributeName"] for key in key_schema])
@@ -203,15 +213,8 @@ class DynamoHandler(BaseResponse):
         actual_attrs = [item["AttributeName"] for item in attr]
         actual_attrs.sort()
         if actual_attrs != expected_attrs:
-            er = "com.amazonaws.dynamodb.v20111205#ValidationException"
-            return self.error(
-                er,
-                "One or more parameter values were invalid: "
-                "Some index key attributes are not defined in AttributeDefinitions. "
-                "Keys: "
-                + str(expected_attrs)
-                + ", AttributeDefinitions: "
-                + str(actual_attrs),
+            return self._throw_attr_error(
+                actual_attrs, expected_attrs, global_indexes or local_secondary_indexes
             )
         # get the stream specification
         streams = body.get("StreamSpecification")
@@ -231,6 +234,62 @@ class DynamoHandler(BaseResponse):
             er = "com.amazonaws.dynamodb.v20111205#ResourceInUseException"
             return self.error(er, "Resource in use")
 
+    def _throw_attr_error(self, actual_attrs, expected_attrs, indexes):
+        def dump_list(list_):
+            return str(list_).replace("'", "")
+
+        er = "com.amazonaws.dynamodb.v20111205#ValidationException"
+        err_head = "One or more parameter values were invalid: "
+        if len(actual_attrs) > len(expected_attrs):
+            if indexes:
+                return self.error(
+                    er,
+                    err_head
+                    + "Some AttributeDefinitions are not used. AttributeDefinitions: "
+                    + dump_list(actual_attrs)
+                    + ", keys used: "
+                    + dump_list(expected_attrs),
+                )
+            else:
+                return self.error(
+                    er,
+                    err_head
+                    + "Number of attributes in KeySchema does not exactly match number of attributes defined in AttributeDefinitions",
+                )
+        elif len(actual_attrs) < len(expected_attrs):
+            if indexes:
+                return self.error(
+                    er,
+                    err_head
+                    + "Some index key attributes are not defined in AttributeDefinitions. Keys: "
+                    + dump_list(list(set(expected_attrs) - set(actual_attrs)))
+                    + ", AttributeDefinitions: "
+                    + dump_list(actual_attrs),
+                )
+            else:
+                return self.error(
+                    er, "Invalid KeySchema: Some index key attribute have no definition"
+                )
+        else:
+            if indexes:
+                return self.error(
+                    er,
+                    err_head
+                    + "Some index key attributes are not defined in AttributeDefinitions. Keys: "
+                    + dump_list(list(set(expected_attrs) - set(actual_attrs)))
+                    + ", AttributeDefinitions: "
+                    + dump_list(actual_attrs),
+                )
+            else:
+                return self.error(
+                    er,
+                    err_head
+                    + "Some index key attributes are not defined in AttributeDefinitions. Keys: "
+                    + dump_list(expected_attrs)
+                    + ", AttributeDefinitions: "
+                    + dump_list(actual_attrs),
+                )
+
     def delete_table(self):
         name = self.body["TableName"]
         table = self.dynamodb_backend.delete_table(name)
@@ -651,7 +710,7 @@ class DynamoHandler(BaseResponse):
                 range_comparison = None
                 range_values = []
 
-            if "=" not in hash_key_expression:
+            if not re.search("[^<>]=", hash_key_expression):
                 return self.error(
                     "com.amazonaws.dynamodb.v20111205#ValidationException",
                     "Query key condition not supported",
@@ -1156,3 +1215,19 @@ class DynamoHandler(BaseResponse):
         except ValueError:
             er = "com.amazonaws.dynamodb.v20111205#TableAlreadyExistsException"
             return self.error(er, "Table already exists: %s" % target_table_name)
+
+    def restore_table_to_point_in_time(self):
+        body = self.body
+        target_table_name = body.get("TargetTableName")
+        source_table_name = body.get("SourceTableName")
+        try:
+            restored_table = self.dynamodb_backend.restore_table_to_point_in_time(
+                target_table_name, source_table_name
+            )
+            return dynamo_json_dump(restored_table.describe())
+        except KeyError:
+            er = "com.amazonaws.dynamodb.v20111205#SourceTableNotFoundException"
+            return self.error(er, "Source table not found: %s" % source_table_name)
+        except ValueError:
+            er = "com.amazonaws.dynamodb.v20111205#TableAlreadyExistsException"
+            return self.error(er, "Table already exists: %s" % target_table_name)
