@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 import json
 import re
 from datetime import datetime
@@ -11,7 +10,7 @@ from moto.core.responses import AWSServiceSpec
 from moto.core.responses import BaseResponse
 from moto.core.responses import xml_to_json_response
 from moto.core.utils import tags_from_query_string
-from .exceptions import EmrError
+from .exceptions import ValidationException
 from .models import emr_backends
 from .utils import steps_from_query_string, Unflattener, ReleaseLabel
 
@@ -129,7 +128,7 @@ class ElasticMapReduceResponse(BaseResponse):
     @generate_boto3_response("DescribeCluster")
     def describe_cluster(self):
         cluster_id = self._get_param("ClusterId")
-        cluster = self.backend.get_cluster(cluster_id)
+        cluster = self.backend.describe_cluster(cluster_id)
         template = self.response_template(DESCRIBE_CLUSTER_TEMPLATE)
         return template.render(cluster=cluster)
 
@@ -277,6 +276,7 @@ class ElasticMapReduceResponse(BaseResponse):
             log_uri=self._get_param("LogUri"),
             job_flow_role=self._get_param("JobFlowRole"),
             service_role=self._get_param("ServiceRole"),
+            auto_scaling_role=self._get_param("AutoScalingRole"),
             steps=steps_from_query_string(self._get_list_prefix("Steps.member")),
             visible_to_all_users=self._get_bool_param("VisibleToAllUsers", False),
             instance_attrs=instance_attrs,
@@ -320,11 +320,7 @@ class ElasticMapReduceResponse(BaseResponse):
                     "Only one AMI version and release label may be specified. "
                     "Provided AMI: {0}, release label: {1}."
                 ).format(ami_version, release_label)
-                raise EmrError(
-                    error_type="ValidationException",
-                    message=message,
-                    template="error_json",
-                )
+                raise ValidationException(message=message)
         else:
             if ami_version:
                 kwargs["requested_ami_version"] = ami_version
@@ -339,18 +335,10 @@ class ElasticMapReduceResponse(BaseResponse):
                 ReleaseLabel(release_label) < ReleaseLabel("emr-5.7.0")
             ):
                 message = "Custom AMI is not allowed"
-                raise EmrError(
-                    error_type="ValidationException",
-                    message=message,
-                    template="error_json",
-                )
+                raise ValidationException(message=message)
             elif ami_version:
                 message = "Custom AMI is not supported in this version of EMR"
-                raise EmrError(
-                    error_type="ValidationException",
-                    message=message,
-                    template="error_json",
-                )
+                raise ValidationException(message=message)
 
         step_concurrency_level = self._get_param("StepConcurrencyLevel")
         if step_concurrency_level:
@@ -529,7 +517,7 @@ class ElasticMapReduceResponse(BaseResponse):
     @generate_boto3_response("PutAutoScalingPolicy")
     def put_auto_scaling_policy(self):
         cluster_id = self._get_param("ClusterId")
-        cluster = self.backend.get_cluster(cluster_id)
+        cluster = self.backend.describe_cluster(cluster_id)
         instance_group_id = self._get_param("InstanceGroupId")
         auto_scaling_policy = self._get_param("AutoScalingPolicy")
         instance_group = self.backend.put_auto_scaling_policy(
@@ -665,6 +653,7 @@ DESCRIBE_CLUSTER_TEMPLATE = """<DescribeClusterResponse xmlns="http://elasticmap
       <SecurityConfiguration>{{ cluster.security_configuration }}</SecurityConfiguration>
       {% endif %}
       <ServiceRole>{{ cluster.service_role }}</ServiceRole>
+      <AutoScalingRole>{{ cluster.auto_scaling_role }}</AutoScalingRole>
       <Status>
         <State>{{ cluster.state }}</State>
         <StateChangeReason>
