@@ -1,4 +1,3 @@
-from boto3 import Session
 from moto.core import BaseBackend, BaseModel
 from datetime import datetime
 from .exceptions import (
@@ -7,7 +6,7 @@ from .exceptions import (
 )
 import random
 import string
-from moto.core.utils import get_random_hex
+from moto.core.utils import get_random_hex, BackendDict
 from moto.core import ACCOUNT_ID
 
 
@@ -135,12 +134,4 @@ class KinesisVideoBackend(BaseBackend):
     # add methods from here
 
 
-kinesisvideo_backends = {}
-for region in Session().get_available_regions("kinesisvideo"):
-    kinesisvideo_backends[region] = KinesisVideoBackend(region)
-for region in Session().get_available_regions(
-    "kinesisvideo", partition_name="aws-us-gov"
-):
-    kinesisvideo_backends[region] = KinesisVideoBackend(region)
-for region in Session().get_available_regions("kinesisvideo", partition_name="aws-cn"):
-    kinesisvideo_backends[region] = KinesisVideoBackend(region)
+kinesisvideo_backends = BackendDict(KinesisVideoBackend, "kinesisvideo")
