@@ -1,20 +1,32 @@
 """Handles Route53 API requests, invokes method and returns response."""
+from functools import wraps
 from urllib.parse import parse_qs, urlparse
 
 from jinja2 import Template
 import xmltodict
 
 from moto.core.responses import BaseResponse
-from moto.core.exceptions import InvalidToken
-from moto.route53.exceptions import Route53ClientError, InvalidPaginationToken
+from moto.route53.exceptions import Route53ClientError, InvalidChangeBatch
 from moto.route53.models import route53_backend
 
 XMLNS = "https://route53.amazonaws.com/doc/2013-04-01/"
 
 
+def error_handler(f):
+    @wraps(f)
+    def _wrapper(*args, **kwargs):
+        try:
+            return f(*args, **kwargs)
+        except Route53ClientError as e:
+            return e.code, e.get_headers(), e.get_body()
+
+    return _wrapper
+
+
 class Route53(BaseResponse):
     """Handler for Route53 requests and responses."""
 
+    @error_handler
     def list_or_create_hostzone_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
 
@@ -64,22 +76,21 @@ class Route53(BaseResponse):
         template = Template(LIST_HOSTED_ZONES_BY_NAME_RESPONSE)
         return 200, headers, template.render(zones=zones, dnsname=dnsname, xmlns=XMLNS)
 
+    @error_handler
     def get_or_delete_hostzone_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
         parsed_url = urlparse(full_url)
         zoneid = parsed_url.path.rstrip("/").rsplit("/", 1)[1]
-        the_zone = route53_backend.get_hosted_zone(zoneid)
-        if not the_zone:
-            return no_such_hosted_zone_error(zoneid, headers)
 
         if request.method == "GET":
+            the_zone = route53_backend.get_hosted_zone(zoneid)
             template = Template(GET_HOSTED_ZONE_RESPONSE)
-
             return 200, headers, template.render(zone=the_zone)
         elif request.method == "DELETE":
             route53_backend.delete_hosted_zone(zoneid)
             return 200, headers, DELETE_HOSTED_ZONE_RESPONSE
 
+    @error_handler
     def rrset_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
 
@@ -87,9 +98,6 @@ class Route53(BaseResponse):
         method = request.method
 
         zoneid = parsed_url.path.rstrip("/").rsplit("/", 2)[1]
-        the_zone = route53_backend.get_hosted_zone(zoneid)
-        if not the_zone:
-            return no_such_hosted_zone_error(zoneid, headers)
 
         if method == "POST":
             elements = xmltodict.parse(self.body)
@@ -104,9 +112,24 @@ class Route53(BaseResponse):
                     ]["Change"]
                 ]
 
-            error_msg = route53_backend.change_resource_record_sets(
-                the_zone, change_list
-            )
+            # Enforce quotas https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-requests-changeresourcerecordsets
+            #  - A request cannot contain more than 1,000 ResourceRecord elements. When the value of the Action element is UPSERT, each ResourceRecord element is counted twice.
+            effective_rr_count = 0
+            for value in change_list:
+                record_set = value["ResourceRecordSet"]
+                if (
+                    "ResourceRecords" not in record_set
+                    or not record_set["ResourceRecords"]
+                ):
+                    continue
+                resource_records = list(record_set["ResourceRecords"].values())[0]
+                effective_rr_count += len(resource_records)
+                if value["Action"] == "UPSERT":
+                    effective_rr_count += len(resource_records)
+            if effective_rr_count > 1000:
+                raise InvalidChangeBatch
+
+            error_msg = route53_backend.change_resource_record_sets(zoneid, change_list)
             if error_msg:
                 return 400, headers, error_msg
 
@@ -121,7 +144,9 @@ class Route53(BaseResponse):
             if start_type and not start_name:
                 return 400, headers, "The input is not valid"
 
-            record_sets = the_zone.get_record_sets(start_type, start_name)
+            record_sets = route53_backend.list_resource_record_sets(
+                zoneid, start_type=start_type, start_name=start_name
+            )
             return 200, headers, template.render(record_sets=record_sets)
 
     def health_check_response(self, request, full_url, headers):
@@ -218,6 +243,7 @@ class Route53(BaseResponse):
             template = Template(GET_CHANGE_RESPONSE)
             return 200, headers, template.render(change_id=change_id, xmlns=XMLNS)
 
+    @error_handler
     def list_or_create_query_logging_config_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
 
@@ -225,12 +251,10 @@ class Route53(BaseResponse):
             json_body = xmltodict.parse(self.body)["CreateQueryLoggingConfigRequest"]
             hosted_zone_id = json_body["HostedZoneId"]
             log_group_arn = json_body["CloudWatchLogsLogGroupArn"]
-            try:
-                query_logging_config = route53_backend.create_query_logging_config(
-                    self.region, hosted_zone_id, log_group_arn
-                )
-            except Route53ClientError as r53error:
-                return r53error.code, {}, r53error.description
+
+            query_logging_config = route53_backend.create_query_logging_config(
+                self.region, hosted_zone_id, log_group_arn
+            )
 
             template = Template(CREATE_QUERY_LOGGING_CONFIG_RESPONSE)
             headers["Location"] = query_logging_config.location
@@ -244,22 +268,14 @@ class Route53(BaseResponse):
             hosted_zone_id = self._get_param("hostedzoneid")
             next_token = self._get_param("nexttoken")
             max_results = self._get_int_param("maxresults")
-            try:
-                try:
-                    # The paginator picks up named arguments, returns tuple.
-                    # pylint: disable=unbalanced-tuple-unpacking
-                    (
-                        all_configs,
-                        next_token,
-                    ) = route53_backend.list_query_logging_configs(
-                        hosted_zone_id=hosted_zone_id,
-                        next_token=next_token,
-                        max_results=max_results,
-                    )
-                except InvalidToken as exc:
-                    raise InvalidPaginationToken() from exc
-            except Route53ClientError as r53error:
-                return r53error.code, {}, r53error.description
+
+            # The paginator picks up named arguments, returns tuple.
+            # pylint: disable=unbalanced-tuple-unpacking
+            (all_configs, next_token,) = route53_backend.list_query_logging_configs(
+                hosted_zone_id=hosted_zone_id,
+                next_token=next_token,
+                max_results=max_results,
+            )
 
             template = Template(LIST_QUERY_LOGGING_CONFIGS_RESPONSE)
             return (
@@ -272,18 +288,16 @@ class Route53(BaseResponse):
                 ),
             )
 
+    @error_handler
     def get_or_delete_query_logging_config_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
         parsed_url = urlparse(full_url)
         query_logging_config_id = parsed_url.path.rstrip("/").rsplit("/", 1)[1]
 
         if request.method == "GET":
-            try:
-                query_logging_config = route53_backend.get_query_logging_config(
-                    query_logging_config_id
-                )
-            except Route53ClientError as r53error:
-                return r53error.code, {}, r53error.description
+            query_logging_config = route53_backend.get_query_logging_config(
+                query_logging_config_id
+            )
             template = Template(GET_QUERY_LOGGING_CONFIG_RESPONSE)
             return (
                 200,
@@ -292,27 +306,10 @@ class Route53(BaseResponse):
             )
 
         elif request.method == "DELETE":
-            try:
-                route53_backend.delete_query_logging_config(query_logging_config_id)
-            except Route53ClientError as r53error:
-                return r53error.code, {}, r53error.description
+            route53_backend.delete_query_logging_config(query_logging_config_id)
             return 200, headers, ""
 
 
-def no_such_hosted_zone_error(zoneid, headers=None):
-    if not headers:
-        headers = {}
-    headers["X-Amzn-ErrorType"] = "NoSuchHostedZone"
-    headers["Content-Type"] = "text/xml"
-    error_response = f"""<ErrorResponse xmlns="{XMLNS}">
-        <Error>
-            <Code>NoSuchHostedZone</Code>
-            <Message>Zone {zoneid} Not Found</Message>
-        </Error>
-    </ErrorResponse>"""
-    return 404, headers, error_response
-
-
 LIST_TAGS_FOR_RESOURCE_RESPONSE = """
 <ListTagsForResourceResponse xmlns="https://route53.amazonaws.com/doc/2015-01-01/">
     <ResourceTagSet>
@@ -334,11 +331,55 @@ CHANGE_TAGS_FOR_RESOURCE_RESPONSE = """<ChangeTagsForResourceResponse xmlns="htt
 </ChangeTagsForResourceResponse>
 """
 
-LIST_RRSET_RESPONSE = """<ListResourceRecordSetsResponse xmlns="https://route53.amazonaws.com/doc/2012-12-12/">
+LIST_RRSET_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
+<ListResourceRecordSetsResponse xmlns="https://route53.amazonaws.com/doc/2012-12-12/">
    <ResourceRecordSets>
-   {% for record_set in record_sets %}
-      {{ record_set.to_xml() }}
-   {% endfor %}
+       {% for record in record_sets %}
+       <ResourceRecordSet>
+           <Name>{{ record.name }}</Name>
+           <Type>{{ record.type_ }}</Type>
+           {% if record.set_identifier %}
+               <SetIdentifier>{{ record.set_identifier }}</SetIdentifier>
+           {% endif %}
+           {% if record.weight %}
+               <Weight>{{ record.weight }}</Weight>
+           {% endif %}
+           {% if record.region %}
+               <Region>{{ record.region }}</Region>
+           {% endif %}
+           {% if record.ttl %}
+               <TTL>{{ record.ttl }}</TTL>
+           {% endif %}
+           {% if record.failover %}
+               <Failover>{{ record.failover }}</Failover>
+           {% endif %}
+           {% if record.geo_location %}
+           <GeoLocation>
+           {% for geo_key in ['ContinentCode','CountryCode','SubdivisionCode'] %}
+             {% if record.geo_location[geo_key] %}<{{ geo_key }}>{{ record.geo_location[geo_key] }}</{{ geo_key }}>{% endif %}
+           {% endfor %}
+           </GeoLocation>
+           {% endif %}
+           {% if record.alias_target %}
+           <AliasTarget>
+               <HostedZoneId>{{ record.alias_target['HostedZoneId'] }}</HostedZoneId>
+               <DNSName>{{ record.alias_target['DNSName'] }}</DNSName>
+               <EvaluateTargetHealth>{{ record.alias_target['EvaluateTargetHealth'] }}</EvaluateTargetHealth>
+           </AliasTarget>
+           {% else %}
+           <ResourceRecords>
+               {% for resource in record.records %}
+               <ResourceRecord>
+                   <Value><![CDATA[{{ resource }}]]></Value>
+               </ResourceRecord>
+               {% endfor %}
+           </ResourceRecords>
+           {% endif %}
+           {% if record.health_check %}
+               <HealthCheckId>{{ record.health_check }}</HealthCheckId>
+           {% endif %}
+        </ResourceRecordSet>
+       {% endfor %}
    </ResourceRecordSets>
    <IsTruncated>false</IsTruncated>
 </ListResourceRecordSetsResponse>"""
