@@ -1,3 +1,5 @@
+from moto import settings
+
 from .responses import S3ResponseInstance
 
 url_bases = [
@@ -5,6 +7,8 @@ url_bases = [
     r"https?://(?P<bucket_name>[a-zA-Z0-9\-_.]*)\.?s3(.*)\.amazonaws.com",
 ]
 
+url_bases.extend(settings.get_s3_custom_endpoints())
+
 url_paths = {
     # subdomain bucket
     "{0}/$": S3ResponseInstance.bucket_response,
