@@ -10,8 +10,6 @@ from copy import deepcopy
 from typing import Dict
 from xml.sax.saxutils import escape
 
-from boto3 import Session
-
 from moto.core.exceptions import RESTError
 from moto.core import BaseBackend, BaseModel, CloudFormationModel
 from moto.core.utils import (
@@ -20,11 +18,11 @@ from moto.core.utils import (
     unix_time,
     unix_time_millis,
     tags_from_cloudformation_tags_list,
+    BackendDict,
 )
 from .utils import generate_receipt_handle
 from .exceptions import (
     MessageAttributesInvalid,
-    MessageNotInflight,
     QueueDoesNotExist,
     QueueAlreadyExists,
     ReceiptHandleIsInvalid,
@@ -73,6 +71,7 @@ class Message(BaseModel):
         self._body = body
         self.message_attributes = {}
         self.receipt_handle = None
+        self._old_receipt_handles = []
         self.sender_id = DEFAULT_SENDER_ID
         self.sent_timestamp = None
         self.approximate_first_receive_timestamp = None
@@ -178,6 +177,7 @@ class Message(BaseModel):
         if visibility_timeout:
             self.change_visibility(visibility_timeout)
 
+        self._old_receipt_handles.append(self.receipt_handle)
         self.receipt_handle = generate_receipt_handle()
 
     def change_visibility(self, visibility_timeout):
@@ -203,6 +203,16 @@ class Message(BaseModel):
             return True
         return False
 
+    @property
+    def all_receipt_handles(self):
+        return [self.receipt_handle] + self._old_receipt_handles
+
+    def had_receipt_handle(self, receipt_handle):
+        """
+        Check if this message ever had this receipt_handle in the past
+        """
+        return receipt_handle in self.all_receipt_handles
+
 
 class Queue(CloudFormationModel):
     BASE_ATTRIBUTES = [
@@ -247,6 +257,7 @@ class Queue(CloudFormationModel):
 
         self._messages = []
         self._pending_messages = set()
+        self.deleted_messages = set()
 
         now = unix_time()
         self.created_timestamp = now
@@ -323,15 +334,28 @@ class Queue(CloudFormationModel):
 
             setattr(self, camelcase_to_underscores(key), value)
 
-        if attributes.get("RedrivePolicy", None):
+        if attributes.get("RedrivePolicy", None) is not None:
             self._setup_dlq(attributes["RedrivePolicy"])
 
-        if attributes.get("Policy"):
-            self.policy = attributes["Policy"]
+        self.policy = attributes.get("Policy")
 
         self.last_modified_timestamp = now
 
+    @staticmethod
+    def _is_empty_redrive_policy(policy):
+        if isinstance(policy, str):
+            if policy == "" or len(json.loads(policy)) == 0:
+                return True
+        elif isinstance(policy, dict) and len(policy) == 0:
+            return True
+
+        return False
+
     def _setup_dlq(self, policy):
+        if Queue._is_empty_redrive_policy(policy):
+            self.redrive_policy = None
+            self.dead_letter_queue = None
+            return
 
         if isinstance(policy, str):
             try:
@@ -534,7 +558,32 @@ class Queue(CloudFormationModel):
                 [backend.delete_message(self.name, m.receipt_handle) for m in messages]
             else:
                 # Make messages visible again
-                [m.change_visibility(visibility_timeout=0) for m in messages]
+                [
+                    backend.change_message_visibility(
+                        self.name, m.receipt_handle, visibility_timeout=0
+                    )
+                    for m in messages
+                ]
+
+    def delete_message(self, receipt_handle):
+        if receipt_handle in self.deleted_messages:
+            # Already deleted - gracefully handle deleting it again
+            return
+
+        if not any(
+            message.had_receipt_handle(receipt_handle) for message in self._messages
+        ):
+            raise ReceiptHandleIsInvalid()
+
+        # Delete message from queue regardless of pending state
+        new_messages = []
+        for message in self._messages:
+            if message.had_receipt_handle(receipt_handle):
+                self.pending_messages.discard(message)
+                self.deleted_messages.update(message.all_receipt_handles)
+                continue
+            new_messages.append(message)
+        self._messages = new_messages
 
     @classmethod
     def has_cfn_attr(cls, attribute_name):
@@ -733,6 +782,12 @@ class SQSBackend(BaseBackend):
             if queue.fifo_queue:
                 raise MissingParameter("MessageGroupId")
         else:
+            if not queue.fifo_queue:
+                msg = (
+                    "Value {} for parameter MessageGroupId is invalid. "
+                    "Reason: The request include parameter that is not valid for this queue type."
+                ).format(group_id)
+                raise InvalidParameterValue(msg)
             message.group_id = group_id
 
         if message_attributes:
@@ -862,12 +917,14 @@ class SQSBackend(BaseBackend):
 
                 queue.pending_messages.add(message)
                 message.mark_received(visibility_timeout=visibility_timeout)
-                _filter_message_attributes(message, message_attribute_names)
+                # Create deepcopy to not mutate the message state when filtering for attributes
+                message_copy = deepcopy(message)
+                _filter_message_attributes(message_copy, message_attribute_names)
                 if not self.is_message_valid_based_on_retention_period(
                     queue_name, message
                 ):
                     break
-                result.append(message)
+                result.append(message_copy)
                 if len(result) >= count:
                     break
 
@@ -893,26 +950,12 @@ class SQSBackend(BaseBackend):
     def delete_message(self, queue_name, receipt_handle):
         queue = self.get_queue(queue_name)
 
-        if not any(
-            message.receipt_handle == receipt_handle for message in queue._messages
-        ):
-            raise ReceiptHandleIsInvalid()
-
-        # Delete message from queue regardless of pending state
-        new_messages = []
-        for message in queue._messages:
-            if message.receipt_handle == receipt_handle:
-                queue.pending_messages.discard(message)
-                continue
-            new_messages.append(message)
-        queue._messages = new_messages
+        queue.delete_message(receipt_handle)
 
     def change_message_visibility(self, queue_name, receipt_handle, visibility_timeout):
         queue = self.get_queue(queue_name)
         for message in queue._messages:
-            if message.receipt_handle == receipt_handle:
-                if message.visible:
-                    raise MessageNotInflight
+            if message.had_receipt_handle(receipt_handle):
 
                 visibility_timeout_msec = int(visibility_timeout) * 1000
                 given_visibility_timeout = unix_time_millis() + visibility_timeout_msec
@@ -925,7 +968,7 @@ class SQSBackend(BaseBackend):
                     )
 
                 message.change_visibility(visibility_timeout)
-                if message.visible:
+                if message.visible and message in queue.pending_messages:
                     # If the message is visible again, remove it from pending
                     # messages.
                     queue.pending_messages.remove(message)
@@ -1064,10 +1107,4 @@ class SQSBackend(BaseBackend):
         return True
 
 
-sqs_backends = {}
-for region in Session().get_available_regions("sqs"):
-    sqs_backends[region] = SQSBackend(region)
-for region in Session().get_available_regions("sqs", partition_name="aws-us-gov"):
-    sqs_backends[region] = SQSBackend(region)
-for region in Session().get_available_regions("sqs", partition_name="aws-cn"):
-    sqs_backends[region] = SQSBackend(region)
+sqs_backends = BackendDict(SQSBackend, "sqs")
