@@ -14,7 +14,6 @@ from .exceptions import (
     EmptyBatchRequest,
     InvalidAddress,
     InvalidAttributeName,
-    MessageNotInflight,
     ReceiptHandleIsInvalid,
     BatchEntryIdsNotDistinct,
 )
@@ -123,17 +122,11 @@ class SQSResponse(BaseResponse):
         except ValueError:
             return ERROR_MAX_VISIBILITY_TIMEOUT_RESPONSE, dict(status=400)
 
-        try:
-            self.sqs_backend.change_message_visibility(
-                queue_name=queue_name,
-                receipt_handle=receipt_handle,
-                visibility_timeout=visibility_timeout,
-            )
-        except MessageNotInflight as e:
-            return (
-                "Invalid request: {0}".format(e.description),
-                dict(status=e.status_code),
-            )
+        self.sqs_backend.change_message_visibility(
+            queue_name=queue_name,
+            receipt_handle=receipt_handle,
+            visibility_timeout=visibility_timeout,
+        )
 
         template = self.response_template(CHANGE_MESSAGE_VISIBILITY_RESPONSE)
         return template.render()
@@ -176,15 +169,6 @@ class SQSResponse(BaseResponse):
                         "Message": e.description,
                     }
                 )
-            except MessageNotInflight as e:
-                error.append(
-                    {
-                        "Id": entry["id"],
-                        "SenderFault": "false",
-                        "Code": "AWS.SimpleQueueService.MessageNotInflight",
-                        "Message": e.description,
-                    }
-                )
 
         template = self.response_template(CHANGE_MESSAGE_VISIBILITY_BATCH_RESPONSE)
         return template.render(success=success, errors=error)
