@@ -1,12 +1,10 @@
 from uuid import uuid4
-from boto3 import Session
 from moto.core import BaseBackend, BaseModel
 from moto.wafv2 import utils
 
-# from moto.ec2.models import elbv2_backends
 from .utils import make_arn_for_wacl, pascal_to_underscores_dict
 from .exceptions import WAFV2DuplicateItemException
-from moto.core.utils import iso_8601_datetime_with_milliseconds
+from moto.core.utils import iso_8601_datetime_with_milliseconds, BackendDict
 import datetime
 from collections import OrderedDict
 
@@ -115,15 +113,7 @@ class WAFV2Backend(BaseBackend):
     #     return ec2_backends[self.region_name]
 
 
-wafv2_backends = {}
+wafv2_backends = BackendDict(WAFV2Backend, "waf-regional")
 wafv2_backends[GLOBAL_REGION] = WAFV2Backend(
     GLOBAL_REGION
 )  # never used? cloudfront is global and uses us-east-1
-for region in Session().get_available_regions("waf-regional"):
-    wafv2_backends[region] = WAFV2Backend(region)
-for region in Session().get_available_regions(
-    "waf-regional", partition_name="aws-us-gov"
-):
-    wafv2_backends[region] = WAFV2Backend(region)
-for region in Session().get_available_regions("waf-regional", partition_name="aws-cn"):
-    wafv2_backends[region] = WAFV2Backend(region)
